@@ -12,13 +12,14 @@
 #include <kodi/addon-instance/PVR.h>
 #include "Channels.h"
 #include "Recordings.h"
+#include "utilities/GenreMapper.h"
 
 namespace NextPVR
 {
   class ATTR_DLL_LOCAL EPG
   {
   public:
-    EPG(const std::shared_ptr<InstanceSettings>& settings, Request& request, Recordings& recordings, Channels& channels);
+    EPG(const std::shared_ptr<InstanceSettings>& settings, Request& request, Recordings& recordings, Channels& channels, GenreMapper& genreMapper);
     PVR_ERROR GetEPGForChannel(int channelUid, time_t start, time_t end, kodi::addon::PVREPGTagsResultSet& results);
 
   private:
@@ -30,5 +31,6 @@ namespace NextPVR
     Request& m_request;
     Recordings& m_recordings;
     Channels& m_channels;
+    GenreMapper& m_genreMapper;
   };
 } // namespace NextPVR
